@@ -1,7 +1,7 @@
 #ABSTRACT: Exception class for MooX::Ipc::Cmd role
 package MooX::Ipc::Cmd::Exception;
 use Moo;
-our $VERSION = '1.0.2'; #VERSION
+our $VERSION = '1.0.3'; #VERSION
 extends 'Throwable::Error';
 has 'stderr'      => (is => 'ro', predicate => 1,);
 has 'cmd'         => (is => 'ro', required  => 1,);
@@ -28,7 +28,7 @@ has +message => (
             $str .= " failed with exit status " . $self->exit_status;
             if ($self->has_stderr && defined $self->stderr)
             {
-                $str = "\nSTDERR is :\n" . join("\n  ", @{$self->stderr});
+                $str .= "\nSTDERR is :\n" . join("\n  ", @{$self->stderr});
             }
         }
         return $str;
@@ -49,7 +49,7 @@ MooX::Ipc::Cmd::Exception - Exception class for MooX::Ipc::Cmd role
 
 =head1 VERSION
 
-version 1.0.2
+version 1.0.3
 
 =head1 AUTHOR
 
